**Example 1: 开通专业版**

开通专业版

Input: 

```
tccli yunjing OpenProVersion --cli-unfold-argument  \
    --MachineType CVM \
    --MachineRegion ap-guangzhou \
    --Quuids add4a78a-0d59-11e8-b7ab-00e081e1a5c5
```

Output: 
```
{
    "Response": {
        "RequestId": "354f4ac3-8546-4516-8c8a-69e3ab73aa8a"
    }
}
```

